@@ -1,23 +1,23 @@
 ''' Utilities for manipulating package-level settings. '''
 
 import json
-from os.path import join, expanduser, exists
+from pathlib import Path
 import os
 from io import open
 import warnings
 
+from .utils import listify
+
 __all__ = ['set_option', 'set_options', 'get_option']
 
 _config_name = 'pybids_config.json'
 
-conf_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                         'layout', 'config', '{}.json')
+conf_path = str(Path(__file__).absolute().parent.joinpath('layout', 'config', '{}.json'))
 _default_settings = {
-    # XXX 0.14: Remove bids-nodot option (and file)
     'config_paths': {
-        name: conf_path.format(name) for name in ['bids', 'derivatives', 'bids-nodot']},
-    # XXX 0.14: Set to True
-    'extension_initial_dot': None,
+        name: conf_path.format(name) for name in ['bids', 'derivatives']},
+    # XXX 0.16: Remove
+    'extension_initial_dot': True,
 }
 
 
@@ -30,10 +30,14 @@ def set_option(key, value):
     """
     if key not in _settings:
         raise ValueError("Invalid pybids setting: '%s'" % key)
-    # XXX 0.14: Raise error
-    if (key, value) == ("extension_initial_dot", False):
-        warnings.warn("Setting 'extension_initial_dot' to False will be disabled in "
-                      "pybids 0.14", FutureWarning)
+    # XXX 0.16: Remove
+    elif key == "extension_initial_dot":
+        if value is not True:
+            raise ValueError(f"Cannot set {key!r} to {value!r} as of pybids 0.14. "
+                             "This setting is always True, and will be removed "
+                             "entirely in 0.16.")
+        warnings.warn("Setting 'extension_initial_dot' will be removed in pybids 0.16.",
+                      FutureWarning)
     _settings[key] = value
 
 
@@ -68,12 +72,10 @@ def from_file(filenames, error_on_missing=True):
         error_on_missing (bool): If True, raises an error if a file doesn't
             exist.
     """
-    if isinstance(filenames, str):
-        filenames = [filenames]
+    filenames = listify(filenames)
     for f in filenames:
-        if exists(f):
-            with open(f, 'r', encoding='utf-8') as fobj:
-                settings = json.load(fobj)
+        if Path(f).exists():
+            settings = json.loads(Path(f).read_text(encoding='utf-8'))
             _settings.update(settings)
         elif error_on_missing:
             raise ValueError("Config file '%s' does not exist." % f)
@@ -98,8 +100,8 @@ def _update_from_standard_locations():
     current directory--with later files taking precedence over earlier ones.
     """
     locs = [
-        join(expanduser('~'), _config_name),
-        join('.', _config_name)
+        Path.home() / _config_name,
+        Path('.') / _config_name
     ]
     if 'PYBIDS_CONFIG' in os.environ:
         locs.insert(1, os.environ['PYBIDS_CONFIG'])
