@@ -12,6 +12,7 @@ from pathlib import Path
 
 import sqlalchemy as sa
 from sqlalchemy.orm import aliased
+from sqlalchemy.sql.expression import cast
 from bids_validator import BIDSValidator
 
 from ..utils import listify, natural_sort
@@ -54,7 +55,7 @@ class BIDSLayout(object):
         directories).
     derivatives : bool or str or list, optional
         Specifies whether and/or which
-        derivatives to to index. If True, all pipelines found in the
+        derivatives to index. If True, all pipelines found in the
         derivatives/ subdirectory will be indexed. If a str or list, gives
         the paths to one or more derivatives directories to index. If False
         or None, the derivatives/ directory is ignored during indexing, and
@@ -134,6 +135,12 @@ class BIDSLayout(object):
 
         # Initialize a completely new layout and index the dataset
         if not load_db:
+            # If root dataset is a derivative, set config accordingly
+            if description and description.get("DatasetType") == "derivative":
+                if validate:
+                    validate_derivative_paths([root], self)
+                config = ["bids", "derivatives"]
+
             init_args = dict(root=root, absolute_paths=absolute_paths,
                              derivatives=derivatives, config=config)
 
@@ -745,45 +752,32 @@ class BIDSLayout(object):
             for name, val in filters.items():
                 tag_alias = aliased(Tag)
 
-                val_list = list(listify(val)) if val is not None else [None]
-                if not val_list:
-                    continue
+                if isinstance(val, (list, tuple)) and len(val) == 1:
+                    val = val[0]
 
-                none = any_ = False
-                if None in val_list:
-                    none = True
-                    val_list.remove(None)
-                if Query.NONE in val_list:
-                    none = True
-                    val_list.remove(Query.NONE)
-                if Query.ANY in val_list:
-                    any_ = True
-                    val_list.remove(Query.ANY)
-
-                if none and any_:
-                    # Always true, apply no filter
-                    continue
-
-                # Baseline, use join, start accumulating clauses
                 join_method = query.join
-                val_clauses = []
 
-                # NONE and ANY get special treatment
-                if none:
+                if val is None or val == Query.NONE:
                     join_method = query.outerjoin
-                    val_clauses.append(tag_alias._value.is_(None))
-                if any_:
-                    val_clauses.append(tag_alias._value.isnot(None))
-
-                # Any remaining values
-                if regex:
-                    val_clauses.extend([tag_alias._value.op('REGEXP')(str(v))
-                                        for v in val_list])
-                elif val_list:
-                    val_clauses.append(tag_alias._value.in_(val_list))
-
-                # Looking for intersection with list of vals, so use OR
-                val_clause = sa.or_(*val_clauses) if len(val_clauses) > 1 else val_clauses[0]
+                    val_clause = tag_alias._value.is_(None)
+                elif val == Query.OPTIONAL:
+                    continue
+                elif val == Query.ANY:
+                    val_clause = tag_alias._value.isnot(None)
+                elif regex:
+                    if isinstance(val, (list, tuple)):
+                        val_clause = sa.or_(*[
+                            tag_alias._value.op('REGEXP')(str(v))
+                            for v in val
+                        ])
+                    else:
+                        val_clause = tag_alias._value.op('REGEXP')(str(val))
+                else:
+                    vals = listify(val)
+                    if isinstance(vals[0], int):
+                        val_clause = cast(tag_alias._value, sa.Integer).in_(vals)
+                    else:
+                        val_clause = tag_alias._value.in_(vals)
 
                 query = join_method(
                     tag_alias,
@@ -1331,4 +1325,5 @@ class BIDSLayout(object):
 class Query(enum.Enum):
     """Enums for use with BIDSLayout.get()."""
     NONE = 1 # Entity must not be present
-    ANY = 2  # Entity must be defined, but with an arbitrary value
+    REQUIRED = ANY = 2  # Entity must be defined, but with an arbitrary value
+    OPTIONAL = 3  # Entity may or may not be defined
