@@ -14,10 +14,12 @@ import pytest
 from bids.layout import BIDSLayout, Query
 from bids.layout.models import Config
 from bids.layout.index import BIDSLayoutIndexer
+from bids.layout.utils import PaddedInt
 from bids.tests import get_test_data_path
 from bids.utils import natural_sort
 
 from bids.exceptions import (
+    BIDSDerivativesValidationError,
     BIDSValidationError,
     NoMatchError,
     TargetError,
@@ -141,6 +143,47 @@ def test_get_file(layout_ds005_derivs):
     assert not layout.get_file('/absolute/bleargh')
 
 
+class TestDerivativeAsRoot:
+    def test_dataset_without_datasettype_parsed_as_raw(self):
+        dataset_path = Path("ds005_derivs", "format_errs", "no_dataset_type")
+        unvalidated = BIDSLayout(
+            Path(get_test_data_path())/dataset_path,
+            validate=False
+        )
+        assert len(unvalidated.get()) == 4
+        with pytest.raises(ValueError):
+            unvalidated.get(desc="preproc")
+
+        validated = BIDSLayout(Path(get_test_data_path())/dataset_path)
+        assert len(validated.get()) == 1
+
+    def test_dataset_missing_generatedby_fails_validation(self):
+        dataset_path = Path("ds005_derivs", "format_errs", "no_pipeline_description")
+        with pytest.raises(BIDSDerivativesValidationError):
+            BIDSLayout(Path(get_test_data_path())/dataset_path)
+
+
+    def test_correctly_formatted_derivative_loads_as_derivative(self):
+        dataset_path = Path("ds005_derivs", "dummy")
+        layout = BIDSLayout(Path(get_test_data_path())/dataset_path)
+        assert len(layout.get()) == 4
+        assert len(layout.get(desc="preproc")) == 3
+
+    @pytest.mark.parametrize(
+        "dataset_path",
+        [
+            Path("ds005_derivs", "dummy"),
+            Path("ds005_derivs", "format_errs", "no_pipeline_description")
+        ]
+    )
+    def test_derivative_datasets_load_with_no_validation(self, dataset_path):
+        layout = BIDSLayout(
+            Path(get_test_data_path())/dataset_path,
+            validate=False
+        )
+        assert len(layout.get()) == 4
+        assert len(layout.get(desc="preproc")) == 3
+
 def test_get_metadata(layout_7t_trt):
     target = 'sub-03/ses-2/func/sub-03_ses-2_task-' \
              'rest_acq-fullbrain_run-2_bold.nii.gz'
@@ -321,6 +364,23 @@ def test_get_val_enum_any(layout_7t_trt):
     assert len(bold_files) == 2
 
 
+def test_get_val_enum_any_optional(layout_7t_trt, layout_ds005):
+    # layout with sessions
+    query = {
+        "subject": "01",
+        "run": 1,
+        "suffix": "bold",
+    }
+    bold_files = layout_7t_trt.get(session=Query.OPTIONAL, **query)
+    assert len(bold_files) == 3
+
+    # layout without sessions
+    bold_files = layout_ds005.get(session=Query.REQUIRED, **query)
+    assert not bold_files
+    bold_files = layout_ds005.get(session=Query.OPTIONAL, **query)
+    assert len(bold_files) == 1
+
+
 def test_get_return_sorted(layout_7t_trt):
     bids_files = layout_7t_trt.get(target='subject')
     paths = [r.path for r in bids_files]
@@ -652,7 +712,7 @@ def test_get_with_wrong_dtypes(layout_7t_trt):
     ''' Test automatic dtype sanitization. '''
     l = layout_7t_trt
     assert (l.get(run=1) == l.get(run='1') == l.get(run=np.int64(1)) ==
-            l.get(run=[1, '15']))
+            l.get(run=[1, '15']) == l.get(run='01'))
     assert not l.get(run='not_numeric')
     assert l.get(session=1) == l.get(session='1')
 
@@ -712,19 +772,6 @@ def test_get_with_invalid_filters(layout_ds005):
     l.get(**filters)
 
 
-def test_get_with_query_constants_in_match_list(layout_ds005):
-    l = layout_ds005
-    get1 = l.get(subject='12', run=1, suffix='bold')
-    get_none = l.get(subject='12', run=None, suffix='bold')
-    get_any = l.get(subject='12', run=Query.ANY, suffix='bold')
-    get1_and_none = l.get(subject='12', run=[None, 1], suffix='bold')
-    get1_and_any = l.get(subject='12', run=[Query.ANY, 1], suffix='bold')
-    get_none_and_any = l.get(subject='12', run=[Query.ANY, Query.NONE], suffix='bold')
-    assert set(get1_and_none) == set(get1) | set(get_none)
-    assert set(get1_and_any) == set(get1) | set(get_any)
-    assert set(get_none_and_any) == set(get_none) | set(get_any)
-
-
 def test_load_layout(layout_synthetic_nodb, db_dir):
     db_path = str(db_dir / 'tmp_db')
     layout_synthetic_nodb.save(db_path)
@@ -735,3 +782,43 @@ def test_load_layout(layout_synthetic_nodb, db_dir):
     cm2 = reloaded.connection_manager
     for attr in ['root', 'absolute_paths', 'config', 'derivatives']:
         assert getattr(cm1.layout_info, attr) == getattr(cm2.layout_info, attr)
+
+
+def test_load_layout_config_not_overwritten(layout_synthetic_nodb, tmpdir):
+    modified_dataset_path = tmpdir/"modified"
+    shutil.copytree(layout_synthetic_nodb.root, modified_dataset_path)
+
+    # Save index
+    db_path = str(tmpdir / 'tmp_db')
+    BIDSLayout(modified_dataset_path).save(db_path)
+
+    # Update dataset_description.json
+    dataset_description = modified_dataset_path/"dataset_description.json"
+    with dataset_description.open('r') as f:
+        description = json.load(f)
+    description["DatasetType"] = "derivative"
+    with dataset_description.open('w') as f:
+        json.dump(description, f)
+
+    # Reload
+    db_layout = BIDSLayout(modified_dataset_path, database_path=db_path)
+    fresh_layout = BIDSLayout(modified_dataset_path, validate=False)
+    cm1 = db_layout.connection_manager
+    cm2 = fresh_layout.connection_manager
+    for attr in ['root', 'absolute_paths', 'derivatives']:
+        assert getattr(cm1.layout_info, attr) == getattr(cm2.layout_info, attr)
+
+    assert cm1.layout_info.config != cm2.layout_info.config
+
+
+def test_padded_run_roundtrip(layout_ds005):
+    for run in (1, "1", "01"):
+        res = layout_ds005.get(subject="01", task="mixedgamblestask",
+                               run=run, extension=".nii.gz")
+        assert len(res) == 1
+    boldfile = res[0]
+    ents = boldfile.get_entities()
+    assert isinstance(ents["run"], PaddedInt)
+    assert ents["run"] == 1
+    newpath = layout_ds005.build_path(ents, absolute_paths=False)
+    assert newpath == "sub-01/func/sub-01_task-mixedgamblestask_run-01_bold.nii.gz"
