@@ -4,6 +4,8 @@ import json
 from collections import namedtuple, OrderedDict, Counter, defaultdict
 import itertools
 from functools import reduce
+import re
+import fnmatch
 
 import numpy as np
 import pandas as pd
@@ -335,21 +337,24 @@ class BIDSStatsModelsNode:
 
         groups = defaultdict(list)
 
-        # sanitize grouping entities, otherwise weird things can happen
-        group_by = list(set(group_by) & VALID_GROUPING_ENTITIES)
-
         # Get unique values in each grouping variable and construct indexing DF
         entities = [obj.entities for obj in objects]
         df = pd.DataFrame.from_records(entities)
 
+        # Single-run tasks and single-session subjects may not have entities
+        dummy_groups = {"run", "session"} - set(df.columns)
+
+        # sanitize grouping entities, otherwise weird things can happen
+        group_by = set(group_by) & VALID_GROUPING_ENTITIES - dummy_groups
+
         # Verify all columns in group_by exist and raise sensible error if not
-        missing_vars = list(set(group_by) - set(df.columns))
+        missing_vars = list(group_by - set(df.columns))
         if missing_vars:
             raise ValueError("group_by contains variable(s) {} that could not "
                              "be found in the entity index.".format(missing_vars) )
 
         # Restrict DF to only grouping columns
-        df = df.loc[:, group_by]
+        df = df.loc[:, list(group_by)]
 
         unique_vals = {col: df[col].dropna().unique().tolist() for col in group_by}
 
@@ -520,6 +525,15 @@ class BIDSStatsModelsNode:
         return [c for c in self._collections if matches_entities(c, filters)]
 
 
+def expand_wildcards(selectors, pool):
+    out = list(selectors)
+    for spec in selectors:
+        if re.search(r'[\*\?\[\]]', spec):
+            idx = out.index(spec)
+            out[idx:idx + 1] = fnmatch.filter(pool, spec)
+    return out
+
+
 class BIDSStatsModelsNodeOutput:
     """Represents a single node in a BIDSStatsModelsGraph.
 
@@ -597,6 +611,8 @@ class BIDSStatsModelsNodeOutput:
             else:
                 var_names.append(int_name)
 
+        var_names = expand_wildcards(var_names, df.columns)
+
         # Verify all X names are actually present
         missing = list(set(var_names) - set(df.columns))
         if missing:
@@ -642,7 +658,9 @@ class BIDSStatsModelsNodeOutput:
 
             # Take the intersection of variables and Model.X (var_names), ignoring missing
             # variables (usually contrasts)
-            coll.variables = {v: coll.variables[v] for v in var_names if v in coll.variables}
+            coll.variables = {v: coll.variables[v]
+                              for v in expand_wildcards(var_names, coll.variables)
+                              if v in coll.variables}
             if not coll.variables:
                 continue
 
